..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

.. _project_info:

Project Info
============

Maintainers
-----------

Project Team Lead (PTL)
~~~~~~~~~~~~~~~~~~~~~~~


+------------------------------+---------------------------------------------+
|       Contact                |             Area of interest                |
+------------------------------+---------------------------------------------+
| | Feilong Wang               |  * Chief Architect                          |
| | flwang (irc)               |  * Release management                       |
| | flwang@catalyst.net.nz     |  * Community management                     |
| | flwang@qq.com              |  * Core team management                     |
| |                            |  * Road Map                                 |
+------------------------------+---------------------------------------------+

| *If you would like to refactor whole Zaqar or have UX/community/other
   issues please contact me.*


Project Core maintainers
~~~~~~~~~~~~~~~~~~~~~~~~

+------------------------------+---------------------------------------------+
|       Contact                |             Area of interest                |
+------------------------------+---------------------------------------------+
| | Xiyuan Wang                |  * Zaqar related questions or bugs.         |
| | wxy (irc) UTC0200-UTC1000  |  * Production problem for Zaqar.            |
| | wangxiyuan1007@gmail.com   |  * Integration with container.              |
| |                            |                                             |
+------------------------------+---------------------------------------------+
| | Hao Wang                   |  * Introduce interesting and helpful        |
| |                            |    features                                 |
| | wanghao (irc)              |  * Bug Fix and Code Optimization            |
| | sxmatch1986@gmail.com      |  * Notification Service                     |
| |                            |                                             |
+------------------------------+---------------------------------------------+
| | Thomas Herve               |  * Websocket                                |
| | therve (irc)               |  * Swift backend                            |
| | therve@redhat.com          |                                             |
| |                            |                                             |
+------------------------------+---------------------------------------------+

| *All cores from this list are reviewing all changes that are proposed to Zaqar.
  To avoid duplication of efforts, please contact them before starting work on
  your code.*


Storage Backend Maintainers reviewers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

+------------------------------+---------------------------------------------+
|       Contact                |             Area of interest                |
+------------------------------+---------------------------------------------+
| | Hao Wang                   |  * MongoDB                                  |
| | wanghao (irc)              |                                             |
| | sxmatch1986@gmail.com      |                                             |
+------------------------------+---------------------------------------------+
| | gecong                     |  * Swift                                    |
| | gecong (irc)               |                                             |
| | ge.cong@zte.com.cn         |                                             |
| |                            |                                             |
+------------------------------+---------------------------------------------+
| | gengchc2                   |  * Redis                                    |
| | gengchc (irc)              |                                             |
| | geng.changcai2@zte.com.cn  |                                             |
| |                            |                                             |
+------------------------------+---------------------------------------------+
| | Feilong Wang               |  * SqlAlchemy                               |
| | flwang (irc)               |                                             |
| | flwang@catalyst.net.nz     |                                             |
| |                            |                                             |
+------------------------------+---------------------------------------------+

| *All cores from this list are responsible for maintaining the storage backend.
  To avoid duplication of efforts, please contact them before starting working
  on your own backends.*


Useful links
------------
- `Source code`_
- `Project space`_
- `Bugs`_
- `Patches on review`_


Where can I discuss and propose changes?
----------------------------------------
- Our IRC channel: **#openstack-zaqar** on **irc.freenode.net**;
- Bi-Weekly Zaqar team meeting (in IRC): **#openstack-meeting-3** on
  **irc.freenode.net**, held on Monday at 14:00 UTC;
- OpenStack mailing list: **openstack-discuss@lists.openstack.org** (see
  `Subscription and usage instructions`_);
- `Zaqar team on Launchpad`_: Answers/Bugs/Blueprints.


.. references:

.. _Source code: https://github.com/openstack/zaqar
.. _Project space: https://launchpad.net/zaqar
.. _Bugs: https://bugs.launchpad.net/zaqar
.. _Patches on review: https://review.opendev.org/#/q/status:open+zaqar,n,z
.. _IRC logs: http://irclog.perlgeek.de/openstack-zaqar
.. _Subscription and usage instructions: http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss
.. _Zaqar team on Launchpad: https://launchpad.net/zaqar
